jan: thuban/Extensions/profiling __init__.py,1.1,1.2

cvs@intevation.de cvs at intevation.de
Tue Nov 16 22:33:29 CET 2004


Author: jan

Update of /thubanrepository/thuban/Extensions/profiling
In directory doto:/tmp/cvs-serv13660

Modified Files:
	__init__.py 
Log Message:
Added registry entry and the importing of the actual profiling module.


Index: __init__.py
===================================================================
RCS file: /thubanrepository/thuban/Extensions/profiling/__init__.py,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- __init__.py	31 Oct 2003 16:02:52 -0000	1.1
+++ __init__.py	16 Nov 2004 21:33:27 -0000	1.2
@@ -1,6 +1,22 @@
-# Copyright (c) 2003 by Intevation GmbH
+# Copyright (c) 2003, 2004 by Intevation GmbH
 # Authors:
 # Jan-Oliver Wagner <jan at intevation.de>
 #
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with Thuban for details.
+
+# import the actual module
+import profiling
+
+# perform the registration of the extension
+from Thuban import _
+from Thuban.UI.extensionregistry import ExtensionDesc, ext_registry
+
+ext_registry.add(ExtensionDesc(
+    name = 'profiling',
+    version = '1.0.0',
+    authors= [ 'Bernhard Herzog' ],
+    copyright = '2003, 2004 Intevation GmbH',
+    desc = _("Provide a profiler and a timer\n"
+             "for screen rendering.")))
+
@@ -1,6 +1,22 @@
 # Authors:
-# Jan-Oliver Wagner <jan at intevation.de>
+# Jan-Oliver Wagner <jan at intevation.de> (2003, 2004)
 #
 # This program is free software under the GPL (>=v2)





More information about the Thuban-devel mailing list

This site is hosted by Intevation GmbH (Datenschutzerklärung und Impressum | Privacy Policy and Imprint)